/**
 * @file retimer_wrapper.c
 *
 * @brief @{Retimer I2C Master wrapper functions.@}
 *
 *******************************************************************************
 *
 * Copyright (2014-2020), Cypress Semiconductor Corporation or a subsidiary of
 * Cypress Semiconductor Corporation. All rights reserved.
 *
 * This software, including source code, documentation and related materials
 * (“Software”), is owned by Cypress Semiconductor Corporation or one of its
 * subsidiaries (“Cypress”) and is protected by and subject to worldwide patent
 * protection (United States and foreign), United States copyright laws and
 * international treaty provisions. Therefore, you may use this Software only
 * as provided in the license agreement accompanying the software package from
 * which you obtained this Software (“EULA”).
 *
 * If no EULA applies, Cypress hereby grants you a personal, nonexclusive,
 * non-transferable license to copy, modify, and compile the Software source
 * code solely for use in connection with Cypress’s integrated circuit
 * products. Any reproduction, modification, translation, compilation, or
 * representation of this Software except as specified above is prohibited
 * without the express written permission of Cypress. Disclaimer: THIS SOFTWARE
 * IS PROVIDED AS-IS, WITH NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Cypress reserves the
 * right to make changes to the Software without notice. Cypress does not
 * assume any liability arising out of the application or use of the Software
 * or any product or circuit described in the Software. Cypress does not
 * authorize its products for use in any products where a malfunction or
 * failure of the Cypress product may reasonably be expected to result in
 * significant property damage, injury or death (“High Risk Product”). By
 * including Cypress’s product in a High Risk Product, the manufacturer of such
 * system or application assumes all risk of such use and in doing so agrees to
 * indemnify Cypress against all liability.
 */
#include <app.h>
#if BB_RETIMER_ENABLE
#include <bb_retimer.h>
#endif /* BB_RETIMER_ENABLE */

/* Retimer I2C writes */
bool retimer_write_wrapper(uint8_t slave_address, uint8_t offset, uint8_t* data, uint8_t num_bytes)
{
    if(RTM_I2CMasterSendStart(slave_address, RTM_I2C_WRITE_XFER_MODE, RETIMER_I2C_TIMEOUT) != RTM_I2C_MSTR_NO_ERROR)
        goto end_transfer;
    
    if(RTM_I2CMasterWriteByte(offset, RETIMER_I2C_TIMEOUT) != RTM_I2C_MSTR_NO_ERROR)
        goto end_transfer;

    if(RTM_I2CMasterWriteByte(num_bytes, RETIMER_I2C_TIMEOUT) != RTM_I2C_MSTR_NO_ERROR)
        goto end_transfer;

    while(num_bytes--)
        if(RTM_I2CMasterWriteByte(*data++, RETIMER_I2C_TIMEOUT) != RTM_I2C_MSTR_NO_ERROR)
            goto end_transfer;

    if(RTM_I2CMasterSendStop(RETIMER_I2C_TIMEOUT) != RTM_I2C_MSTR_NO_ERROR)
        return false;
    
    return true;
    
end_transfer:
    RTM_I2CMasterSendStop(RETIMER_I2C_TIMEOUT);
    return false;
}

/* Retimer I2C read wrapper */
bool retimer_read_wrapper (uint8_t slave_address, uint8_t offset, uint8_t* data_buffer, uint8_t num_bytes)
{
    uint8_t rd_byte[num_bytes];
    uint32_t status;
    
    if(RTM_I2CMasterSendStart(slave_address, RTM_I2C_WRITE_XFER_MODE, RETIMER_I2C_TIMEOUT) != RTM_I2C_MSTR_NO_ERROR)
        goto end_transfer;
    
    if(RTM_I2CMasterWriteByte(offset, RETIMER_I2C_TIMEOUT) != RTM_I2C_MSTR_NO_ERROR)
        goto end_transfer;
    
    if(RTM_I2CMasterSendRestart(slave_address, RTM_I2C_READ_XFER_MODE, RETIMER_I2C_TIMEOUT) != RTM_I2C_MSTR_NO_ERROR)
        goto end_transfer;
    
    while(num_bytes--)
    {
        status = RTM_I2CMasterReadByte(num_bytes ? RTM_I2C_ACK_DATA : RTM_I2C_NAK_DATA, &rd_byte[num_bytes], RETIMER_I2C_TIMEOUT );
        if(status != RTM_I2C_MSTR_NO_ERROR)
            goto end_transfer;         
        else
            *data_buffer++ = rd_byte[num_bytes];
    }

    if(RTM_I2CMasterSendStop(RETIMER_I2C_TIMEOUT) != RTM_I2C_MSTR_NO_ERROR)
        return false;
    
    return true;
        
end_transfer:
    RTM_I2CMasterSendStop(RETIMER_I2C_TIMEOUT);
    return false;
}

/* End of File */

