/**
 * @file srom.h
 *
 * @brief @{SROM Code header file.@}
 * This file shall be updated during ROM code base updates only. 
 */

/*
 * Copyright (2014-2019), Cypress Semiconductor Corporation or a subsidiary of
 * Cypress Semiconductor Corporation. All rights reserved.
 *
 * This software, including source code, documentation and related materials
 * (“Software”), is owned by Cypress Semiconductor Corporation or one of its
 * subsidiaries (“Cypress”) and is protected by and subject to worldwide patent
 * protection (United States and foreign), United States copyright laws and
 * international treaty provisions. Therefore, you may use this Software only
 * as provided in the license agreement accompanying the software package from
 * which you obtained this Software (“EULA”).
 *
 * If no EULA applies, Cypress hereby grants you a personal, nonexclusive,
 * non-transferable license to copy, modify, and compile the Software source
 * code solely for use in connection with Cypress’s integrated circuit
 * products. Any reproduction, modification, translation, compilation, or
 * representation of this Software except as specified above is prohibited
 * without the express written permission of Cypress. Disclaimer: THIS SOFTWARE
 * IS PROVIDED AS-IS, WITH NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Cypress reserves the
 * right to make changes to the Software without notice. Cypress does not
 * assume any liability arising out of the application or use of the Software
 * or any product or circuit described in the Software. Cypress does not
 * authorize its products for use in any products where a malfunction or
 * failure of the Cypress product may reasonably be expected to result in
 * significant property damage, injury or death (“High Risk Product”). By
 * including Cypress’s product in a High Risk Product, the manufacturer of such
 * system or application assumes all risk of such use and in doing so agrees to
 * indemnify Cypress against all liability.
 */

#ifndef _SROM_H_
#define _SROM_H_

#include <config.h>
#include <stdio.h>
#include <string.h>
#include "srom_config.h"

#if CCG_SROM_CODE_ENABLE
#ifdef CCG6
#include "srom_vars_ccg6.h"
#endif /* CCG6 */
#else /* !CCG_SROM_CODE_ENABLE */
#include "srom_vars_default.h"
#endif /* CCG_SROM_CODE_ENABLE */

/************************************************************************
* ROM/Flash function and variable access macro redirection.
* Macro mapping section in each srom_vars_<device>.h file need to be 
* updated when there is any change in ROM code base.
* Macro mapping sections must include all the CALL_MAP functions of
* the code base. Each call mapping function can be mapped to
* either direct function or variable call 
* or through call_in/call_out function or get_in variable as per the ROM
* code definition of the device. 
************************************************************************/
#if CCG_SROM_CODE_ENABLE
#define CALL_MAP(str)  call_##str(str)
#else /* !CCG_SROM_CODE_ENABLE */
#define CALL_MAP(str)  (str)
#endif /* CCG_SROM_CODE_ENABLE */

#endif /* _SROM_H_ */

