/**
 * @file srom_config.h
 *
 * @brief @{SROM Code Configuration file.@}
 * This file shall be updated only during ROM code base updates. 
 */

/*
 * Copyright (2014-2019), Cypress Semiconductor Corporation or a subsidiary of
 * Cypress Semiconductor Corporation. All rights reserved.
 *
 * This software, including source code, documentation and related materials
 * (“Software”), is owned by Cypress Semiconductor Corporation or one of its
 * subsidiaries (“Cypress”) and is protected by and subject to worldwide patent
 * protection (United States and foreign), United States copyright laws and
 * international treaty provisions. Therefore, you may use this Software only
 * as provided in the license agreement accompanying the software package from
 * which you obtained this Software (“EULA”).
 *
 * If no EULA applies, Cypress hereby grants you a personal, nonexclusive,
 * non-transferable license to copy, modify, and compile the Software source
 * code solely for use in connection with Cypress’s integrated circuit
 * products. Any reproduction, modification, translation, compilation, or
 * representation of this Software except as specified above is prohibited
 * without the express written permission of Cypress. Disclaimer: THIS SOFTWARE
 * IS PROVIDED AS-IS, WITH NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Cypress reserves the
 * right to make changes to the Software without notice. Cypress does not
 * assume any liability arising out of the application or use of the Software
 * or any product or circuit described in the Software. Cypress does not
 * authorize its products for use in any products where a malfunction or
 * failure of the Cypress product may reasonably be expected to result in
 * significant property damage, injury or death (“High Risk Product”). By
 * including Cypress’s product in a High Risk Product, the manufacturer of such
 * system or application assumes all risk of such use and in doing so agrees to
 * indemnify Cypress against all liability.
 */

#ifndef _SROM_CONFIG_H_
#define _SROM_CONFIG_H_

#include <config.h>
#include <stdio.h>
#include <string.h>

/************************************************************************
* Device specific SROM configuration.
* Configurations in this file can be used across modules for ROM function
* pointer or ROM variable declaration.
* Or any device specific ROM workarounds.
************************************************************************/
#if CCG_SROM_CODE_ENABLE

#ifdef CCG6
#define CCG6_SROM_CODE_ENABLE   (1u)
#define SROM_CODE_SCB_I2C       (1u)
#define SROM_CODE_APP_PDO       (1u)
#define SROM_CODE_PD_PD         (1u)
#define SROM_CODE_PD_PE         (1u)
#define SROM_CODE_PD_PROT       (1u)
#define SROM_CODE_SYS_BOOT      (1u)
#define SROM_CODE_SYS_GPIO      (1u)
#define SROM_CODE_SYS_SYS       (1u)
#else /* !CCG6 */
#error "Selected Device does not support SROM code."
#endif

#else /* !CCG_SROM_CODE_ENABLE */
#define SROM_CODE_SCB_I2C       (0u)
#define SROM_CODE_APP_PDO       (0u)
#define SROM_CODE_PD_PD         (0u)
#define SROM_CODE_PD_PE         (0u)
#define SROM_CODE_PD_PROT       (0u)
#define SROM_CODE_SYS_BOOT      (0u)
#define SROM_CODE_SYS_GPIO      (0u)
#define SROM_CODE_SYS_SYS       (0u)
#endif /* CCG_SROM_CODE_ENABLE */

#endif /* _SROM_CONFIG_H_ */

