/**
 * @file srom_vars_ccg6.c
 *
 * @brief @{SROM Code source file.@}
 * This file shall be updated during ROM code base updates only. 
 *
 *******************************************************************************
 *
 * Copyright (2014-2019), Cypress Semiconductor Corporation or a subsidiary of
 * Cypress Semiconductor Corporation. All rights reserved.
 *
 * This software, including source code, documentation and related materials
 * (“Software”), is owned by Cypress Semiconductor Corporation or one of its
 * subsidiaries (“Cypress”) and is protected by and subject to worldwide patent
 * protection (United States and foreign), United States copyright laws and
 * international treaty provisions. Therefore, you may use this Software only
 * as provided in the license agreement accompanying the software package from
 * which you obtained this Software (“EULA”).
 *
 * If no EULA applies, Cypress hereby grants you a personal, nonexclusive,
 * non-transferable license to copy, modify, and compile the Software source
 * code solely for use in connection with Cypress’s integrated circuit
 * products. Any reproduction, modification, translation, compilation, or
 * representation of this Software except as specified above is prohibited
 * without the express written permission of Cypress. Disclaimer: THIS SOFTWARE
 * IS PROVIDED AS-IS, WITH NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Cypress reserves the
 * right to make changes to the Software without notice. Cypress does not
 * assume any liability arising out of the application or use of the Software
 * or any product or circuit described in the Software. Cypress does not
 * authorize its products for use in any products where a malfunction or
 * failure of the Cypress product may reasonably be expected to result in
 * significant property damage, injury or death (“High Risk Product”). By
 * including Cypress’s product in a High Risk Product, the manufacturer of such
 * system or application assumes all risk of such use and in doing so agrees to
 * indemnify Cypress against all liability.
 */

#include "srom_vars_ccg6.h"
#include "pdo.h"
#include "dpm.h"
#include "dpm_intern.h"
#include "app.h"
#include "pdss_hal.h"

extern uint8_t is_ccg6_device(void);

#if SROM_CODE_SCB_I2C
extern bool hpi_i2c_cmd_callback(i2c_cb_cmd_t cmd, i2c_scb_state_t i2c_state, uint16_t count);

/* SCB register structures for direct access. */
const PSCB_PRT_REGS_T SCB_PRT[I2C_BLOCK_COUNT] =
{
    SCB_PRT0,
#if (I2C_BLOCK_COUNT > 1)
    SCB_PRT1,
#endif /* (I2C_BLOCK_COUNT > 1) */
#if (I2C_BLOCK_COUNT > 2)
    SCB_PRT2,
#endif /* (I2C_BLOCK_COUNT > 2) */
#if (I2C_BLOCK_COUNT > 3)
    SCB_PRT3 
#endif /* (I2C_BLOCK_COUNT > 3) */
};
#endif /* SROM_CODE_SCB_I2C */

#if SROM_CODE_SYS_GPIO
/* GPIO block address array */
const PGPIO_REGS_T GPIO[] =
{
    GPIO0,
    GPIO1,
    GPIO2,
    GPIO3,
    GPIO4,
    GPIO5
};

/* HSIOM block address array */
const PHSIOM_REGS_T HSIOM[] =
{
    HSIOM0,
    HSIOM1,
    HSIOM2,
    HSIOM3,
    HSIOM4,
    HSIOM5
};
#endif /* SROM_CODE_SYS_GPIO */

const srom_out_cbk_t srom_out_callback =
{
    /* System functions. */
    CyDelayUs,
    CyIntSetVector,
    CyIntEnable,
    CyIntDisable,
    CyEnterCriticalSection,
    CyExitCriticalSection,

    /* Timer functions. */
    timer_start,
    timer_stop,
    timer_stop_range,
    timer_is_running,

    /* HPI Functions. */
    hpi_i2c_cmd_callback,

    /* Utils functions. */
    mem_calculate_byte_checksum,
    mem_copy_word,
    mem_set,
    mem_copy,
    div_round_up,

    /* DPM Functions. */
    dpm_get_info,
    dpm_is_rdo_valid,
    dpm_get_status,

    /* App Functions. */
    app_get_resp_buf,

    /* PD PHY Functions. */
    pd_frs_rx_enable,
    pd_frs_rx_disable,
    pd_frs_tx_enable,
    pd_frs_tx_disable,

    pd_phy_send_bist_cm2,
    pd_phy_abort_bist_cm2,
    pd_phy_abort_tx_msg,
    pd_phy_send_reset,

    pd_phy_is_busy,
    pd_phy_init,
    pd_phy_refresh_roles,
    pd_phy_dis_unchunked_tx,
    pd_phy_send_msg,
    pd_phy_get_rx_packet,
    pd_phy_load_msg,
    pd_is_msg,

    /* Boot functions. */
    get_boot_mode_reason,
};

#if (!SROM_CODE_ENABLE)
const srom_in_cbk_t srom_in_callback =
{
    i2c_slave_ack_ctrl,
    i2c_reset,
    i2c_scb_is_idle,
    i2c_scb_enable_wakeup,
#if (CCG_BOOT == 0)
    i2c_timer_cb,
#endif /* (CCG_BOOT == 0) */
    i2c_scb_0_intr_handler,
#if (I2C_BLOCK_COUNT > 1)
    i2c_scb_1_intr_handler,
#endif /* (I2C_BLOCK_COUNT > 1) */
#if (I2C_BLOCK_COUNT > 2)
    i2c_scb_2_intr_handler,
#endif /* (I2C_BLOCK_COUNT > 2) */
#if (I2C_BLOCK_COUNT > 3)
    i2c_scb_3_intr_handler,
#endif /* (I2C_BLOCK_COUNT > 3) */
    i2c_scb_init,
    i2c_scb_deinit,
    i2c_scb_write,
    /* GPIO Functions. */
    gpio_set_value,
    gpio_read_value,
    gpio_set_drv_mode,
    gpio_int_set_config,
    gpio_get_intr,
    gpio_clear_intr,
    hsiom_set_config,
    gpio_hsiom_set_config,
    gpio_set_lvttl_mode,

    /* System functions */
    sys_set_device_mode,
    sys_get_device_mode,
    sys_get_boot_version,
    sys_get_img1_fw_version,
    sys_get_img2_fw_version,
    sys_get_fw_img1_start_addr,
    sys_get_fw_img2_start_addr,
    sys_get_recent_fw_image,
    sys_get_silicon_id,
    get_silicon_revision,
    sys_get_custom_info_addr,
    sys_get_bcdDevice_version,

    /* PDO Functions. */
    eval_src_cap,
    eval_rdo,

    /* PD Protocol Functions. */
    phy_cbk,
    prl_tmr_cbk,

    pd_prot_init,
    pd_prot_start,
    pd_prot_refresh_roles,

    pd_prot_reset_all,
    pd_prot_reset,
    pd_prot_reset_rx,

    pd_prot_is_busy,
    pd_prot_send_ctrl_msg,
    pd_prot_send_data_msg,
    pd_prot_send_extd__msg,
    pd_prot_send_hard_reset,
    pd_prot_send_cable_reset,
    pd_prot_en_bist_cm2,
    pd_prot_dis_bist_cm2,
    pd_prot_en_bist_test_data,
    pd_prot_dis_bist_test_data,
    pd_prot_set_avoid_retry,
    pd_prot_get_rx_packet,
    pd_prot_frs_rx_enable,
    pd_prot_frs_rx_disable,
    pd_prot_frs_tx_enable,
    pd_prot_frs_tx_disable,
};

#else /* SROM_CODE_ENABLE */

/*
 * Note: These addresses are based on the User SROM code in the CCG6 device. The addresses may need to
 * be changed if using another version of SROM code.
 */
#define SROM_BASE_ADDR	(0x10002000)
    
const srom_in_cbk_t srom_in_callback =
{
    /* SCB Functions */
#if SROM_CODE_SCB_I2C
    (i2c_slave_ack_ctrl_fptr)(SROM_BASE_ADDR + 0x9ec + 1),
    (i2c_reset_fptr)(SROM_BASE_ADDR + 0xa1c + 1),
    (i2c_scb_is_idle_fptr)(SROM_BASE_ADDR + 0xb20 + 1),
    (i2c_scb_enable_wakeup_fptr)(SROM_BASE_ADDR + 0xb4c + 1),
    (i2c_timer_cb_fptr)(SROM_BASE_ADDR + 0xb6c + 1),
    (i2c_scb_0_intr_handler_fptr)(SROM_BASE_ADDR + 0xf9c + 1),
    (i2c_scb_1_intr_handler_fptr)(SROM_BASE_ADDR + 0xfa8 + 1),
    (i2c_scb_2_intr_handler_fptr)(SROM_BASE_ADDR + 0xfb4 + 1),
    (i2c_scb_3_intr_handler_fptr)(SROM_BASE_ADDR + 0xfc0 + 1),
    (i2c_scb_init_fptr)(SROM_BASE_ADDR + 0x100c + 1),
    (i2c_scb_deinit_fptr)(SROM_BASE_ADDR + 0x1184 + 1),
    (i2c_scb_write_fptr)(SROM_BASE_ADDR + 0x1204 + 1),
#endif /* SROM_CODE_SCB_I2C */

    /* GPIO Functions. */
#if SROM_CODE_SYS_GPIO
    (gpio_set_value_fptr)(SROM_BASE_ADDR + 0x0 + 1),
    (gpio_read_value_fptr)(SROM_BASE_ADDR + 0x3c + 1),
    (gpio_set_drv_mode_fptr)(SROM_BASE_ADDR + 0x64 + 1),
    (gpio_int_set_config_fptr)(SROM_BASE_ADDR + 0x90 + 1),
    (gpio_get_intr_fptr)(SROM_BASE_ADDR + 0xc4 + 1),
    (gpio_clear_intr_fptr)(SROM_BASE_ADDR + 0xec + 1),
    (hsiom_set_config_fptr)(SROM_BASE_ADDR + 0x108 + 1),
    (gpio_hsiom_set_config_fptr)(SROM_BASE_ADDR + 0x130 + 1),
    (gpio_set_lvttl_mode_fptr)(SROM_BASE_ADDR + 0x15c + 1),
#endif /* SROM_CODE_SYS_GPIO */

    /* System functions */
#if SROM_CODE_SYS_SYS
    (sys_set_device_mode_fptr)(SROM_BASE_ADDR + 0x178 + 1),
    (sys_get_device_mode_fptr)(SROM_BASE_ADDR + 0x188 + 1),
    (sys_get_boot_version_fptr)(SROM_BASE_ADDR + 0x1a8 + 1),
    (sys_get_img1_fw_version_fptr)(SROM_BASE_ADDR + 0x1ac + 1),
    (sys_get_img2_fw_version_fptr)(SROM_BASE_ADDR + 0x1e4 + 1),
    (sys_get_fw_img1_start_addr_fptr)(SROM_BASE_ADDR + 0x21c + 1),
    (sys_get_fw_img2_start_addr_fptr)(SROM_BASE_ADDR + 0x254 + 1),
    (sys_get_recent_fw_image_fptr)(SROM_BASE_ADDR + 0x28c + 1),
    (sys_get_silicon_id_fptr)(SROM_BASE_ADDR + 0x2d8 + 1),
    (get_silicon_revision_fptr)(SROM_BASE_ADDR + 0x2e8 + 1),
    (sys_get_custom_info_addr_fptr)(SROM_BASE_ADDR + 0x308 + 1),
    (sys_get_bcdDevice_version_fptr)(SROM_BASE_ADDR + 0x330 + 1),
#endif /* SROM_CODE_SYS_SYS */

    /* PDO Functions. */
#if ((SROM_CODE_APP_PDO) || (SROM_CODE_PD_PD))
    (eval_src_cap_fptr)(SROM_BASE_ADDR + 0x828 + 1),
    (eval_rdo_fptr)(SROM_BASE_ADDR + 0x9a4 + 1),
#endif /* ((SROM_CODE_APP_PDO) || (SROM_CODE_PD_PD)) */

    /* PD Protocol layer functions. */
#if SROM_CODE_PD_PROT
    (phy_cbk_fptr)(SROM_BASE_ADDR + 0x18a0 + 1),
    (prl_tmr_cbk_fptr)(SROM_BASE_ADDR + 0x1b5c + 1),
    (pd_prot_init_fptr)(SROM_BASE_ADDR + 0x1bd0 + 1),
    (pd_prot_start_fptr)(SROM_BASE_ADDR + 0x1c08 + 1),
    (pd_prot_refresh_roles_fptr)(SROM_BASE_ADDR + 0x1c28 + 1),
    (pd_prot_reset_all_fptr)(SROM_BASE_ADDR + 0x1c44 + 1),
    (pd_prot_reset_fptr)(SROM_BASE_ADDR + 0x1c8c + 1),
    (pd_prot_reset_rx_fptr)(SROM_BASE_ADDR + 0x1cb4 + 1),
    (pd_prot_is_busy_fptr)(SROM_BASE_ADDR + 0x1cd4 + 1),
    (pd_prot_send_ctrl_msg_fptr)(SROM_BASE_ADDR + 0x1d20 + 1),
    (pd_prot_send_data_msg_fptr)(SROM_BASE_ADDR + 0x1d38 + 1),
    (pd_prot_send_extd__msg_fptr)(SROM_BASE_ADDR + 0x1d54 + 1),
    (pd_prot_send_hard_reset_fptr)(SROM_BASE_ADDR + 0x1d70 + 1),
    (pd_prot_send_cable_reset_fptr)(SROM_BASE_ADDR + 0x1e08 + 1),
    (pd_prot_en_bist_cm2_fptr)(SROM_BASE_ADDR + 0x1e6c + 1),
    (pd_prot_dis_bist_cm2_fptr)(SROM_BASE_ADDR + 0x1e7c + 1),
    (pd_prot_en_bist_test_data_fptr)(SROM_BASE_ADDR + 0x1e8c + 1),
    (pd_prot_dis_bist_test_data_fptr)(SROM_BASE_ADDR + 0x1eac + 1),
    (pd_prot_set_avoid_retry_fptr)(SROM_BASE_ADDR + 0x1ecc + 1),
    (pd_prot_get_rx_packet_fptr)(SROM_BASE_ADDR + 0x1eec + 1),
    (pd_prot_frs_rx_enable_fptr)(SROM_BASE_ADDR + 0x1f00 + 1),
    (pd_prot_frs_rx_disable_fptr)(SROM_BASE_ADDR + 0x1f3c + 1),
    (pd_prot_frs_tx_enable_fptr)(SROM_BASE_ADDR + 0x1f64 + 1),
    (pd_prot_frs_tx_disable_fptr)(SROM_BASE_ADDR + 0x1fa0 + 1),
#endif /* SROM_CODE_PD_PROT */
};
#endif /* SROM_CODE_ENABLE */
 
pd_status_t gl_prot_status[NO_OF_TYPEC_PORTS];
srom_vars_t gl_srom_vars;

#if (__ARMCC_VERSION)
        __attribute__ ((section(".srom_out_callback"), zero_init)) __attribute__((used))
#elif defined (__GNUC__)
        __attribute__ ((section(".srom_out_callback"))) __attribute__((used))
#elif defined (__ICCARM__)
        #pragma location=".srom_out_callback"
#endif /* (__ARMCC_VERSION) */
srom_out_cbk_t *glp_srom_out_cbk;

#if (__ARMCC_VERSION)
        __attribute__ ((section(".srom_in_callback"), zero_init)) __attribute__((used))
#elif defined (__GNUC__)
        __attribute__ ((section(".srom_in_callback"))) __attribute__((used))
#elif defined (__ICCARM__)
        #pragma location=".srom_in_callback"
#endif /* (__ARMCC_VERSION) */
srom_in_cbk_t *glp_srom_in_cbk;

#if (__ARMCC_VERSION)
        __attribute__ ((section(".srom_status_var"), zero_init)) __attribute__((used))
#elif defined (__GNUC__)
        __attribute__ ((section(".srom_status_var"))) __attribute__((used))
#elif defined (__ICCARM__)
        #pragma location=".srom_status_var"
#endif /* (__ARMCC_VERSION) */
srom_vars_t *glp_srom_vars;

void srom_vars_init_ccg6 (uint32_t img1_fw_md_addr, uint32_t img2_fw_md_addr)
{
    int i = 0;
    srom_vars_t *vars;

    memset (&gl_srom_vars, 0, sizeof(srom_vars_t));

    /* Setup the pointers */
    glp_srom_out_cbk = (srom_out_cbk_t *)&srom_out_callback;
    glp_srom_in_cbk = (srom_in_cbk_t *)&srom_in_callback;
    glp_srom_vars = (srom_vars_t *)&gl_srom_vars;

    /*
     * Ensure that the device being used is a CCG6. Otherwise, the SROM content will not match the
     * addresses given above and can cause catastrophic failures.
     */
    if (is_ccg6_device() == false)
    {
        glp_srom_out_cbk = NULL;
        glp_srom_in_cbk = NULL;
        glp_srom_vars = NULL;
        return;
    }

    vars = &gl_srom_vars;

    /* I2C Pointer Setup */
#if SROM_CODE_SCB_I2C
    vars->SCB_PRT = (PSCB_PRT_REGS_T *)SCB_PRT;
#endif /* SROM_CODE_SCB_I2C */

    /* GPIO pointer setup. */
#if SROM_CODE_SYS_GPIO
    vars->GPIO = (PGPIO_REGS_T *)GPIO;
    vars->HSIOM = (PHSIOM_REGS_T *)HSIOM;
#endif /* SROM_CODE_SYS_GPIO */

    /* System */
#if SROM_CODE_SYS_SYS
    /* Pointer to Image-1 FW metadata table. */
    vars->gl_img1_fw_metadata = (sys_fw_metadata_t *)(img1_fw_md_addr);
#if (!CCG_DUALAPP_DISABLE)
    vars->gl_img2_fw_metadata = (sys_fw_metadata_t *)(img2_fw_md_addr);
#endif /* (!CCG_DUALAPP_DISABLE) */

    memset (&vars->gl_invalid_version[0], 0, 8);
    vars->gl_active_fw = SYS_FW_MODE_INVALID;
#endif /* SROM_CODE_SYS_SYS */

    /* PDO Variables. */
    for (i = 0; i < NO_OF_TYPEC_PORTS; i ++)
    {
#if SROM_CODE_APP_PDO
        vars->gl_max_min_cur_pwr[i] = 0;
        vars->gl_contract_power[i] = 0;
        vars->gl_contract_voltage[i] = 0;
        vars->gl_op_cur_power[i] = 0;
#endif /* SROM_CODE_APP_PDO */
#if ((SROM_CODE_PD_PROT) || (SROM_CODE_PD_PD) || (SROM_CODE_PD_PE))
        vars->gl_pd_status[i] = &gl_prot_status[i];
#endif /* ((SROM_CODE_PD_PROT) || (SROM_CODE_PD_PD) || (SROM_CODE_PD_PE)) */
    }

    /*PD Protocol variables */
#if ((SROM_CODE_PD_PROT) || (SROM_CODE_PD_PD) || (SROM_CODE_PD_PE))
    memset (vars->gl_pd_status[0], 0, sizeof(pd_status_t) * NO_OF_TYPEC_PORTS);
#endif /* ((SROM_CODE_PD_PROT) || (SROM_CODE_PD_PD) || (SROM_CODE_PD_PE)) */
}

