/**
 * @file tcc.h
 *
 * @brief @{Test code coverage header file.@}
 */

/*
 * Copyright (2014-2020), Cypress Semiconductor Corporation or a subsidiary of
 * Cypress Semiconductor Corporation. All rights reserved.
 *
 * This software, including source code, documentation and related materials
 * (“Software”), is owned by Cypress Semiconductor Corporation or one of its
 * subsidiaries (“Cypress”) and is protected by and subject to worldwide patent
 * protection (United States and foreign), United States copyright laws and
 * international treaty provisions. Therefore, you may use this Software only
 * as provided in the license agreement accompanying the software package from
 * which you obtained this Software (“EULA”).
 *
 * If no EULA applies, Cypress hereby grants you a personal, nonexclusive,
 * non-transferable license to copy, modify, and compile the Software source
 * code solely for use in connection with Cypress’s integrated circuit
 * products. Any reproduction, modification, translation, compilation, or
 * representation of this Software except as specified above is prohibited
 * without the express written permission of Cypress. Disclaimer: THIS SOFTWARE
 * IS PROVIDED AS-IS, WITH NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Cypress reserves the
 * right to make changes to the Software without notice. Cypress does not
 * assume any liability arising out of the application or use of the Software
 * or any product or circuit described in the Software. Cypress does not
 * authorize its products for use in any products where a malfunction or
 * failure of the Cypress product may reasonably be expected to result in
 * significant property damage, injury or death (“High Risk Product”). By
 * including Cypress’s product in a High Risk Product, the manufacturer of such
 * system or application assumes all risk of such use and in doing so agrees to
 * indemnify Cypress against all liability.
 */

#ifndef _TCC_H_
#define _TCC_H_

#include <stdint.h>
#include <tcc_id.h>

#if TEST_CODE_COVERAGE

/**
 * @brief Initializes the test code coverage raw data.
 *
 * @param func_id Index of the function.
 *
 * @return None.
 */
void tcc_init(void);

/**
 * @brief Set the bit corresponding to function index in raw data.
 *
 * @param func_id Index of the function.
 *
 * @return None.
 */
void tcc_set_func_bit(func_id_t func_id);

/**
 * @brief This function returns test code coverage percentage data
 * That is, percentage of functions executed out of all active functions.
 *
 * @param void
 *
 * @return Percentage in decimal (0-100).
 */
uint8_t tcc_get_percent(void);

/**
 * @brief This function returns raw data size of test code coverage
 *
 * @param None
 *
 * @return Available raw data size in bytes.
 */
uint32_t tcc_get_raw_data_size(void);

/**
 * @brief This function extracts raw data of test code coverage
 *
 * This function returns requested bytes of data into the given buffer
 * from the selected byte offset of raw data
 *
 * @param data Pointer to the byte array to store raw data
 * @param offset Byte offset from where to extract raw data
 * @param size Number of bytes to extract from offset
 *
 * @return Number of bytes extracted.
 */
uint32_t tcc_get_raw_data(uint8_t * data, uint32_t offset, uint32_t size);

#endif /* TEST_CODE_COVERAGE */

#endif /* _TCC_H_ */

/* End of file */
