/**
 * @file tcc_id.h
 *
 * @brief @{Test code coverage function id header file.@}
 */

/*
 * Copyright (2014-2020), Cypress Semiconductor Corporation or a subsidiary of
 * Cypress Semiconductor Corporation. All rights reserved.
 *
 * This software, including source code, documentation and related materials
 * (Software), is owned by Cypress Semiconductor Corporation or one of its
 * subsidiaries (Cypress) and is protected by and subject to worldwide patent
 * protection (United States and foreign), United States copyright laws and
 * international treaty provisions. Therefore, you may use this Software only
 * as provided in the license agreement accompanying the software package from
 * which you obtained this Software (EULA).
 *
 * If no EULA applies, Cypress hereby grants you a personal, nonexclusive,
 * non-transferable license to copy, modify, and compile the Software source
 * code solely for use in connection with Cypresss integrated circuit
 * products. Any reproduction, modification, translation, compilation, or
 * representation of this Software except as specified above is prohibited
 * without the express written permission of Cypress. Disclaimer: THIS SOFTWARE
 * IS PROVIDED AS-IS, WITH NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Cypress reserves the
 * right to make changes to the Software without notice. Cypress does not
 * assume any liability arising out of the application or use of the Software
 * or any product or circuit described in the Software. Cypress does not
 * authorize its products for use in any products where a malfunction or
 * failure of the Cypress product may reasonably be expected to result in
 * significant property damage, injury or death (High Risk Product). By
 * including Cypresss product in a High Risk Product, the manufacturer of such
 * system or application assumes all risk of such use and in doing so agrees to
 * indemnify Cypress against all liability.
 */
#ifndef _TCC_ID_H_
#define _TCC_ID_H_

#include <config.h>

#if TEST_CODE_COVERAGE

/**
 * @typedef func_active_t
 * @brief This enumeration holds all functions under preprocessor conditions.
 * Total number of active enum members will be used for calculating percentage
 * of functions executed
 */
typedef enum _func_active_
{
    FUNC_ACTIVE_COUNT /**< Total number of active functions */
} func_active_t;


/**
 * @typedef func_id_t
 * @brief This enumeration holds all functions as IDs.
 * Function ID value will be corresponding to index in the raw data array.
 * Function ID is used as reference point to create and decode raw data
 * of test code coverage.
 * of functions executed
 */
typedef enum _func_id_
{
    FUNC_ID_COUNT /**< Total number of functions */
} func_id_t;

#endif /* TEST_CODE_COVERAGE */
#endif /* _TCC_ID_H_ */

/* End of file */
